Learn R Programming

FjordLight (version 1.0.1)

cs_BuYlRd: Create a colour palette from blues to reds.

Description

This function will create a lovely, evenly spaced colour palette.

Usage

cs_BuYlRd(n)

Value

A character vector of hexadecimal values.

Arguments

n

The number of colours of blue to red to return.

Author

Bernard Gentili

Examples

Run this code
cs_BuYlRd(10)

Run the code above in your browser using DataLab