Learn R Programming

FjordLight (version 1.0.1)

cs_blye: Create a colour palette from blues to yellows.

Description

This function will create a lovely, evenly spaced colour palette.

Usage

cs_blye(n)

Value

A character vector of hexadecimal values.

Arguments

n

The number of colours of blue to yellow to return.

Author

Bernard Gentili

Examples

Run this code
cs_blye(10)

Run the code above in your browser using DataLab