Learn R Programming

FjordLight (version 1.0.1)

fl_ListFjords: Simply lists the names of fjords with available data.

Description

Run this to determine which character vectors to use when downloading data via fl_DownloadFjord, or a range of other uses within FjordLight.

Usage

fl_ListFjords()

Arguments

Value

A list of currently 7 different character vectors representing a range of fjords in the EU Arctic.

Author

Bernard Gentili

Examples

Run this code
fl_ListFjords()

Run the code above in your browser using DataLab