powered by
This function will create a lovely, evenly spaced colour palette.
cs_BuYlRd(n)
A character vector of hexadecimal values.
The number of colours of blue to red to return.
Bernard Gentili
cs_BuYlRd(10)
Run the code above in your browser using DataLab