powered by
This function will create a lovely, evenly spaced colour palette.
cs_blye(n)
A character vector of hexadecimal values.
The number of colours of blue to yellow to return.
Bernard Gentili
cs_blye(10)
Run the code above in your browser using DataLab