powered by
Run this to determine which character vectors to use when downloading data via fl_DownloadFjord, or a range of other uses within FjordLight.
fl_DownloadFjord
FjordLight
fl_ListFjords()
A list of currently 7 different character vectors representing a range of fjords in the EU Arctic.
Bernard Gentili
Run the code above in your browser using DataLab