fl_topocolorscale: Create a colour palette for bathymetry plots.
Description
This function will create a lovely, evenly spaced colour palette
designed for use with bathymetry plots.
Usage
fl_topocolorscale(v)
Value
A list containing two vectors. First the numeric breaks (brks) that will
be shown as different isobath colours. Second the colours (colors) that will be shown. The
colours are given as hexadecimal values.
Arguments
v
Expects a single negative numeric value.
This should be the maximum depth of the bathymetry.